@@ -1,4 +1,4 @@
-//$Id: dialog-res.h,v 1.6 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.h,v 1.7 2001/10/30 17:34:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -37,6 +37,7 @@ namespace Guikachu
 }
 
 #include "resource.h"
+#include "resource-ref.h"
 #include "dialog-win.h"
 
 #include <vector>
@@ -60,7 +61,7 @@ namespace Guikachu
 	    Property<DialogType>      dialog_type;
 	    Property<vector<string> > buttons;
 	    Property<unsigned int>    default_button;
-	    Property<string>          help_id;
+	    Properties::ResourceRef   help_id;
 	    
 	private:
 	    virtual bool load (StorageNode &node);
