@@ -1,4 +1,4 @@
-//$Id: dialog-win.h,v 1.8 2001/04/14 18:01:39 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win.h,v 1.9 2001/09/15 21:27:39 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#ifndef GUIKATCHU_DIALOG_WIN_H
-#define GUIKATCHU_DIALOG_WIN_H
+#ifndef GUIKACHU_DIALOG_WIN_H
+#define GUIKACHU_DIALOG_WIN_H
 
 namespace Guikachu
 {
@@ -84,4 +84,4 @@ namespace Guikachu
     };
 };
 
-#endif /* !GUIKATCHU_DIALOG_WIN_H */
+#endif /* !GUIKACHU_DIALOG_WIN_H */
