@@ -1,4 +1,4 @@
-//$Id: form-editor.cc,v 1.12 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
+//$Id: form-editor.cc,v 1.15 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -168,35 +168,35 @@ Gnome::CanvasItem* FormEditor::render_text (Gnome::CanvasGroup &group,
     }
 
     // Draw the text
-    gnome_canvas_item_new (text_group->gtkobj (),
-			   gnome_canvas_pixbuf_get_type (),
-			   "pixbuf", clipped_pixbuf,
-			   "x", (double)x,
-			   "y", (double)y,
-			   0);
+    draw_pixbuf (*text_group, clipped_pixbuf, x, y);
     gdk_pixbuf_unref (clipped_pixbuf);
 
     // Draw a transparent background block (to get mouse events for
     // the whole area)
-    {
-	Gnome::CanvasPoints bg_points;
-	using Gnome::Art::Point;
-	
-	bg_points.push_back (Point (x, y));
-	bg_points.push_back (Point (x + width, y));
-	bg_points.push_back (Point (x + width, y + height));
-	bg_points.push_back (Point (x, y + height));
-
-	new Gnome::CanvasPolygon (*text_group, bg_points);
-    }
+    FormEditor::draw_rectangle (*text_group,
+				x, y,
+				x + width, y + height);
     
     return text_group;
 }
 
-GdkPixbuf* clip_pixbuf (GdkPixbuf     *src,
-			GtkAnchorType  anchor,
-			int            clip_width,
-			int            clip_height)
+Gnome::CanvasItem* FormEditor::draw_pixbuf (Gnome::CanvasGroup &group,
+					    GdkPixbuf          *pixbuf,
+					    int                 x = 0,
+					    int                 y = 0)
+{
+    return Gtk::wrap (gnome_canvas_item_new (group.gtkobj (),
+					     gnome_canvas_pixbuf_get_type (),
+					     "pixbuf", pixbuf,
+					     "x", (double) x,
+					     "y", (double) y,
+					     0));
+}
+
+static GdkPixbuf* clip_pixbuf (GdkPixbuf     *src,
+			       GtkAnchorType  anchor,
+			       int            clip_width,
+			       int            clip_height)
 {
     GdkPixbuf *dest;
     
@@ -267,3 +267,17 @@ GdkPixbuf* clip_pixbuf (GdkPixbuf     *src,
     return dest;
 }
 
+Gnome::CanvasItem* FormEditor::draw_rectangle (Gnome::CanvasGroup &group,
+					       int x1, int y1,
+					       int x2, int y2)
+{
+    Gnome::CanvasPoints points;
+    using Gnome::Art::Point;
+
+    points.push_back (Point (x1, y1));
+    points.push_back (Point (x2, y1));
+    points.push_back (Point (x2, y2));
+    points.push_back (Point (x1, y2));
+    
+    return new Gnome::CanvasPolygon (group, points);
+}
