@@ -1,4 +1,4 @@
-//$Id: form-editor.h,v 1.11 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
+//$Id: form-editor.h,v 1.14 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,7 @@
 
 #define GUIKACHU_BGC          "#90B398"
 #define GUIKACHU_FGC          "black"   
-#define GUIKACHU_FGC_DISABLED "#505050"
+#define GUIKACHU_FGC_DISABLED "#757575"
 #define GUIKACHU_SELECTED     "#ecffa8"
 
 
@@ -60,6 +60,17 @@ namespace Guikachu
 					    int x, int y,
 					    GtkAnchorType anchor = GTK_ANCHOR_NW,
 					    int clip_width = 0, int clip_height = 0);
+
+	    // Use this instead of Rectangle canvas items because
+	    // those are shoddy
+	    Gnome::CanvasItem* draw_rectangle (Gnome::CanvasGroup &group,
+					       int x1, int y1,
+					       int x2, int y2);
+	    
+	    Gnome::CanvasItem* draw_pixbuf (Gnome::CanvasGroup &group,
+					    GdkPixbuf          *pixbuf,
+					    int                 x = 0,
+					    int                 y = 0);
 	}
     }
 }
