@@ -1,4 +1,4 @@
-//$Id: graffiti.cc,v 1.8 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.cc,v 1.9 2001/10/19 11:47:44 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -76,7 +76,7 @@ void Graffiti::save (StorageNode &node) const
     StorageNode my_node;
 
     /* Position */
-    my_node = StorageNode (node).add_node ("pos");
+    my_node = node.add_node ("pos");
     my_node.set_prop ("x", x);
     my_node.set_prop ("y", y);
 }
