@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.11 2001/10/09 16:37:13 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.12 2001/10/26 20:46:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,7 +21,6 @@
 #include "form-editor.h"
 
 #include <gnome--/canvas.h>
-#include <gnome--/canvas-polygon.h>
 #include <gnome--/canvas-property.h>
 
 using namespace Guikachu::GUI::FormEditor;
@@ -56,7 +55,7 @@ void ListCanvasItem::update ()
     
     int line_spacing = get_font_height (font_num);
     int text_y = widget->y;
-    int text_x = widget->x + 3;
+    int text_x = widget->x + 2;
     
     for (int i = 0; i < visible_strings; i++)
     {
@@ -73,23 +72,14 @@ void ListCanvasItem::update ()
 	    width = get_string_width (font_num, listitems[0]) + 3;
     }
 
-    int x1 = widget->x;
-    int y1 = widget->y;
-    int x2 = x1 + width;
-    int y2 = y1 + height;
+    int x1 = widget->x - 1;
+    int y1 = widget->y - 1;
+    int x2 = x1 + width + 1;
+    int y2 = y1 + height + 1;
     
-    using Gnome::Art::Point;
     using namespace Gnome::CanvasHelpers;
-    
-    Gnome::CanvasPoints frame_points;
-    
-    frame_points.push_back (Point (x1, y1));
-    frame_points.push_back (Point (x2, y1));
-    frame_points.push_back (Point (x2, y2));
-    frame_points.push_back (Point (x1, y2));
-    frame_points.push_back (Point (x1, y1));
-    
-    *(new Gnome::CanvasPolygon (*group, frame_points))
+
+    *(FormEditor::draw_rectangle (*group, x1, y1, x2, y2))
 	<< width_units (1)
 	<< outline_color (usable ? GUIKACHU_FGC : GUIKACHU_FGC_DISABLED);    
 
