@@ -1,4 +1,4 @@
-//$Id: popup-trigger.h,v 1.8 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.h,v 1.9 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,6 +28,7 @@ namespace Guikachu
 }
 
 #include "widget.h"
+#include "widget-ref.h"
 #include "resizeable.h"
 #include "textual.h"
 
@@ -53,10 +54,10 @@ namespace Guikachu
 	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget                 *create_editor ();
 	    
-	    Property<string> list_id;
+	    Properties::WidgetRef list_id;
 
-	    Property<bool>   usable;
-	    Property<bool>   anchor_right;
+	    Property<bool>        usable;
+	    Property<bool>        anchor_right;
 
 	protected:
 	    virtual int get_auto_width ();
