@@ -1,4 +1,4 @@
-//$Id: scrollbar-canvas.cc,v 1.8 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar-canvas.cc,v 1.10 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -16,12 +16,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+/* This code may need a clean-up, but it Works(tm) at the moment */
+
 #include "scrollbar-canvas.h"
 
 #include "form-editor.h"
 
-#include <gnome--/canvas-rect.h>
-#include <gnome--/canvas-polygon.h>
+#include <gdk-pixbuf/gnome-canvas-pixbuf.h>
 
 using namespace Guikachu::GUI::FormEditor;
 
@@ -34,6 +35,11 @@ ScrollBarCanvasItem::ScrollBarCanvasItem (Widgets::ScrollBar *widget_,
     update ();
 }
 
+static void free_pixdata_gfree (guchar *pixels, gpointer data)
+{
+    g_free (pixels);
+}
+
 void ScrollBarCanvasItem::update ()
 {
     if (group)
@@ -47,7 +53,6 @@ void ScrollBarCanvasItem::update ()
     int height = widget->get_display_height ();
 
     int x1 = widget->x;
-    int x2 = x1 + width;
     int y1 = widget->y;
     int y2 = y1 + height;
 
@@ -55,54 +60,88 @@ void ScrollBarCanvasItem::update ()
     // Step 1: the arrows
     int arrow_width  = width;
     int arrow_height = (arrow_width + 1) / 2;
-    int arrow_left = x1 + 1;
-    int arrow_middle = x1 + 1 + arrow_width / 2;
-    int arrow_right = x1 + arrow_width;
-    using Gnome::Art::Point;
+    // FIXME: sanity checks to ensure width/height things
 
-    Gnome::CanvasPoints up_arrow_points;
-    up_arrow_points.push_back (Point (arrow_left,   y1 + 1 + arrow_height));
-    up_arrow_points.push_back (Point (arrow_middle, y1 + 1));
-    up_arrow_points.push_back (Point (arrow_right,  y1 + 1 + arrow_height));
-    *(new Gnome::CanvasPolygon (*group, up_arrow_points))
-	<< fill_color (GUIKACHU_FGC);
+    guchar *up_pixbuf_data = g_new0 (guchar, arrow_width * arrow_height * 4);
+    guchar *dn_pixbuf_data = g_new0 (guchar, arrow_width * arrow_height * 4);
+    Gdk_Color color (GUIKACHU_FGC);
 
-    Gnome::CanvasPoints dn_arrow_points;
-    dn_arrow_points.push_back (Point (arrow_left,   y2 - arrow_height));
-    dn_arrow_points.push_back (Point (arrow_middle, y2));
-    dn_arrow_points.push_back (Point (arrow_right,  y2 - arrow_height));
-    *(new Gnome::CanvasPolygon (*group, dn_arrow_points))
-	<< fill_color (GUIKACHU_FGC);
+    int row_indent = 0;
+    for (int row = arrow_height; row > 0; row--, row_indent++)
+    {
+	int y_up_offset = arrow_width * (row - 1);
+	int y_dn_offset = arrow_width * (arrow_height - row);
+	
+	int row_max_x = arrow_width - row_indent;
+	
+	for (int x = row_indent; x < row_max_x; x++)
+	{
+	    up_pixbuf_data[((y_up_offset + x) * 4) + 0] = color.red >> 8;
+	    up_pixbuf_data[((y_up_offset + x) * 4) + 1] = color.green >> 8;
+	    up_pixbuf_data[((y_up_offset + x) * 4) + 2] = color.blue >> 8;
+	    up_pixbuf_data[((y_up_offset + x) * 4) + 3] = 255;
 
+	    dn_pixbuf_data[((y_dn_offset + x) * 4) + 0] = color.red >> 8;
+	    dn_pixbuf_data[((y_dn_offset + x) * 4) + 1] = color.green >> 8;
+	    dn_pixbuf_data[((y_dn_offset + x) * 4) + 2] = color.blue >> 8;
+	    dn_pixbuf_data[((y_dn_offset + x) * 4) + 3] = 255;
+	}
+    }
+    
+    
+    GdkPixbuf *up_pixbuf = gdk_pixbuf_new_from_data (up_pixbuf_data,
+						     GDK_COLORSPACE_RGB,
+						     true,
+						     8,
+						     arrow_width, arrow_height,
+						     arrow_width * 4,
+						     free_pixdata_gfree, 0);
+
+    GdkPixbuf *dn_pixbuf = gdk_pixbuf_new_from_data (dn_pixbuf_data,
+						     GDK_COLORSPACE_RGB,
+						     true,
+						     8,
+						     arrow_width, arrow_height,
+						     arrow_width * 4,
+						     free_pixdata_gfree, 0);
+    gnome_canvas_item_new (group->gtkobj (),
+			   gnome_canvas_pixbuf_get_type (),
+			   "pixbuf", up_pixbuf,
+			   "x", (double)(x1),
+			   "y", (double)(y1 + 1),
+			   0);
+    gnome_canvas_item_new (group->gtkobj (),
+			   gnome_canvas_pixbuf_get_type (),
+			   "pixbuf", dn_pixbuf,
+			   "x", (double)(x1),
+			   "y", (double)(y2 - arrow_height - 1),
+			   0);
+    gdk_pixbuf_unref (up_pixbuf);
+    gdk_pixbuf_unref (dn_pixbuf);
+    
     // Step 2: the scrolling range
 
     /* FIXME: the scrolling range should have a minimum width of 1 */
     int range_height = height - 2 * (arrow_height + 2);
-    int range_x1 = x1 + 3;
-    int range_x2 = x2 - 2;
+    int range_width = MAX (width - 4, 0);
+    int range_x1 = x1 + 2;
+    int range_x2 = range_x1 + range_width;
     int range_y1 = y1 + arrow_height + 2;
     int range_y2 = range_y1 + range_height;
     
     /* Data for the GdkBitmap to use as a fill stipple */
-    char stipple_bits[] = { 0x01, 0x02 };
-
-    Gnome::CanvasRect *scroll_range =
-	new Gnome::CanvasRect (*group,
-			       range_x1, range_y1,
-			       range_x2, range_y2);
-    
+    char stipple_bits[] = { 0x02, 0x01 };
     GdkBitmap *stipple = gdk_bitmap_create_from_data (NULL,
 						      stipple_bits,
-						      2, 2);    
-    scroll_range->set_fill_stipple (stipple);
+						      2, 2);
+    
+    *(FormEditor::draw_rectangle (*group,
+				  range_x1, range_y1,
+				  range_x2, range_y2))
+	    << fill_stipple (stipple)
+	    << fill_color (widget->usable ? GUIKACHU_FGC : GUIKACHU_FGC_DISABLED);
     gdk_bitmap_unref (stipple);
 
-    if (widget->usable)
-	scroll_range->set_fill_color (GUIKACHU_FGC);
-    else
-	scroll_range->set_fill_color (GUIKACHU_FGC_DISABLED);
-
-
     // Step 3: The value marker
 
     int value_range_size = widget->max_value - widget->min_value;
@@ -136,17 +175,16 @@ void ScrollBarCanvasItem::update ()
     int slider_bottom = slider_top + slider_size;
     
     // Space around the mark
-
-    *(new Gnome::CanvasRect (*group,
-			     range_x1, slider_top - 1,
-			     range_x2, slider_bottom + 1))
-	<< fill_color (GUIKACHU_BGC);
+    *(FormEditor::draw_rectangle (*group,
+				  range_x1, slider_top - 1,
+				  range_x2, slider_bottom + 1))
+        << fill_color (GUIKACHU_BGC);
 
     // The mark itself
-    *(new Gnome::CanvasRect (*group,
-			     range_x1, slider_top,
-			     range_x2, slider_bottom))
+    *(FormEditor::draw_rectangle (*group,
+				  range_x1, slider_top,
+				  range_x2, slider_bottom))
 	<< fill_color (widget->usable ? GUIKACHU_FGC : GUIKACHU_FGC_DISABLED);
-
+	
     set_canvas_item (group);
 }
