@@ -1,4 +1,4 @@
-//$Id: table.cc,v 1.5 2001/10/10 16:17:46 cactus Exp $ -*- c++ -*-
+//$Id: table.cc,v 1.6 2001/10/23 13:05:51 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -180,11 +180,8 @@ void Table::save_rcp (ostream &ostr) const
     g_free (width_str);
 }
 
-int Table::get_display_width ()
+int Table::get_auto_width ()
 {
-    if (manual_width)
-	return width;
-
     int ret_val = 0;
     
     const vector<int> &columns = column_width;
@@ -194,11 +191,8 @@ int Table::get_display_width ()
     return ret_val;
 }
 
-int Table::get_display_height ()
+int Table::get_auto_height ()
 {
-    if (manual_height)
-	return height;
-
     return 100;
 }
 
