@@ -1,4 +1,4 @@
-//$Id: text-field-canvas.cc,v 1.2 2001/10/18 20:41:42 cactus Exp $ -*- c++ -*-
+//$Id: text-field-canvas.cc,v 1.3 2001/10/26 20:46:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,7 +49,7 @@ void TextFieldCanvasItem::update ()
 	num_lines = height / line_height;
 
     int x = widget->x;
-    int y = widget->y;
+    int y = widget->y + 1;
     
     /* Draw background */
     using Gnome::Art::Point;
@@ -68,7 +68,7 @@ void TextFieldCanvasItem::update ()
     {
 	/* Data for the GdkBitmap to use as an outline stipple */
 	static const char stipple_bits[] = {
-	    0x02, };
+	    0x01, };
 	
 	GdkBitmap *stipple = gdk_bitmap_create_from_data (NULL,
 							  stipple_bits,
