@@ -1,4 +1,4 @@
-//$Id: text-field-prop.cc,v 1.2 2001/09/23 13:13:31 cactus Exp $ -*- c++ -*-
+//$Id: text-field-prop.cc,v 1.3 2001/10/27 13:29:26 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -44,11 +44,6 @@ TextFieldProperties::TextFieldProperties (TextField *res)
     /* Resource ID */
     WidgetProperties::add_general_controls (res, *proptable);
 
-#if 0
-    /* Label */
-    TextualProperties::add_controls (res, *proptable);
-#endif
-    
     /* Usable */
     control = new GUI::ToggleButton (res->usable);
     proptable->add (_("_Usable:"), *manage (control),
