@@ -1,4 +1,4 @@
-//$Id: form-res-io.cc,v 1.20 2001/09/19 16:23:38 cactus Exp $ -*- c++ -*-
+//$Id: form-res-io.cc,v 1.21 2001/10/30 22:42:35 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -55,7 +55,7 @@ bool Form::load (StorageNode &node)
 	}
 	else if (curr_node.name () == "widgets")
 	{
-	    def_button = curr_node.get_prop <string> ("defaultbutton");
+	    def_button = curr_node.get_prop <string> ("default");
 	    
 	    for (StorageNode widget_node = curr_node.children ();
 		 widget_node; widget_node++)
