@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.23 2001/10/19 11:14:33 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.25 2001/10/30 17:34:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,12 +41,12 @@ Form::Form (const string& id):
     Resource (id),
     gui (0),
     title (changed, id),
-    help_id (changed, ""),
-    menu_id (changed, ""),
+    help_id (changed),
+    menu_id (changed),
     modal (changed, false),
     frame (changed, true),
     savebehind (changed, true),
-    def_button (changed, ""),
+    def_button (changed, this),
     x (changed),
     y (changed),
     width (changed, 160),
@@ -78,7 +78,7 @@ void Form::show_ui ()
 Widgets::Widget* Form::create_widget (Widgets::Type  type,
 				      const string  &id_ = "")
 {
-    string id = id_;
+    string id = ResourceManager::validate_id (id_);
     
     if (id == "")
 	id = ResourceManager::create_id (Widgets::type_id_from_type (type));
