@@ -1,4 +1,4 @@
-//$Id: form-res.h,v 1.14 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
+//$Id: form-res.h,v 1.15 2001/10/30 17:34:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,8 +28,10 @@ namespace Guikachu
 }
 
 #include "resource.h"
+#include "resource-ref.h"
 #include "form-win.h"
 #include "form-editor/widget.h"
+#include "form-editor/widget-ref.h"
 
 #include <set>
 
@@ -42,6 +44,7 @@ namespace Guikachu
 	    Guikachu::GUI::FormWindow *gui;
 
 	    set<Widgets::Widget*>  widgets;
+
 	public:
 	    Form (const string& name);
 	    virtual ~Form ();
@@ -49,25 +52,10 @@ namespace Guikachu
 	    virtual Type get_type () const { return RESOURCE_FORM; };
 	    virtual void show_ui ();
 
-	    Property<string> title;
-	    Property<string> help_id;
-	    Property<string> menu_id;
-
-	    Property<bool>   modal;
-	    Property<bool>   frame;
-	    Property<bool>   savebehind;
-
-	    Property<string> def_button;
-
-	    Property<int>    x;
-	    Property<int>    y;
-	    Property<int>    width;
-	    Property<int>    height;
-
+	    // Widget managment
 	    const set<Widgets::Widget*>& get_widgets () const { return widgets; };
 	    Widgets::Widget*             get_widget (const string& id) const;
 	    
-	    // Widget managment
 	    Widgets::Widget* create_widget (Widgets::Type  type,
 					    const string  &id = "");
 	    void remove_widget (Widgets::Widget *widget);
@@ -75,6 +63,23 @@ namespace Guikachu
 	    SigC::Signal1<void, Widgets::Widget*> widget_created;
 	    SigC::Signal1<void, Widgets::Widget*> widget_removed;
 	    SigC::Signal0<void> widget_changed;
+
+	    // Properties
+	    Property<string>        title;
+	    Properties::ResourceRef help_id;
+	    Properties::ResourceRef menu_id;
+
+	    Property<bool>          modal;
+	    Property<bool>          frame;
+	    Property<bool>          savebehind;
+	    
+	    Properties::WidgetRef   def_button;
+
+	    Property<int>           x;
+	    Property<int>           y;
+	    Property<int>           width;
+	    Property<int>           height;
+
 	private:
 	    // Persistance
 	    virtual bool load (StorageNode &node);
