@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.cc,v 1.5 2001/09/19 19:25:15 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.cc,v 1.6 2001/10/27 13:29:26 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -57,8 +57,7 @@ WidgetTreeItem::WidgetTreeItem (Widgets::Widget *widget_):
     list <UI::Info> popup_menu_list;
     popup_menu_list.push_back (
 	UI::Item (UI::Icon (GNOME_STOCK_PIXMAP_TRASH),
-		  _("Remove"),
-		  SigC::slot (this, &WidgetTreeItem::remove_cb)));
+		  _("Remove"), menu_remove.slot ()));
     UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
     
     button_press_event.connect (slot (this, &WidgetTreeItem::button_press_cb));
@@ -84,11 +83,6 @@ int WidgetTreeItem::button_press_cb (GdkEventButton *e)
     return false;
 }
 
-void WidgetTreeItem::remove_cb ()
-{
-    widget->get_form ()->remove_widget (widget);
-}
-
 void WidgetTreeItem::widget_selected_cb (bool selected)
 {
     if (selected)
