@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.33 2001/10/21 20:47:40 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.34 2001/10/27 13:29:26 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -189,11 +189,12 @@ void FormWindow::widget_created_cb (Widgets::Widget *widget)
     canvas_item->drag_motion.connect (slot (this, &FormWindow::widget_drag_motion_cb));
     canvas_item->drag_end.connect (slot (this, &FormWindow::widget_drag_end_cb));
     
-    FormWindow_Helpers::WidgetTreeItem *item = new FormWindow_Helpers::WidgetTreeItem (widget);
-    item->show ();
-    item->activate.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
+    FormWindow_Helpers::WidgetTreeItem *tree_item = new FormWindow_Helpers::WidgetTreeItem (widget);
+    tree_item->show ();
+    tree_item->activate.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
+    tree_item->menu_remove.connect (bind (slot (this, &FormWindow::widget_menu_remove_cb), widget));
     
-    tree->add (*item);
+    tree->add (*tree_item);
 }
 
 void FormWindow::widget_removed_cb (Widgets::Widget *widget)
@@ -246,14 +247,14 @@ void FormWindow::palette_cb (Widgets::Type type)
     Gdk_Window window = canvas->get_window ();
     if (type == Widgets::WIDGET_NONE)
     {
-	Gdk_Cursor cursor (0);
-	window.set_cursor (cursor);
+	window.set_cursor (0);
 	return;
 
     } else {
-	
+
 	Gdk_Cursor cursor (GDK_CROSSHAIR);
 	window.set_cursor (cursor);
+	cursor.destroy ();
     }
     
 			   
