@@ -1,4 +1,4 @@
-//$Id: mainwin-io.cc,v 1.6 2001/09/04 14:54:19 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc,v 1.7 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -175,11 +175,14 @@ void GUI::MainWin::filesel_save_cb (Gtk::FileSelection *fs)
 
 void GUI::MainWin::filesel_open_cb (Gtk::FileSelection *fs)
 {
-    filename = fs->get_filename ();
+    string new_filename = fs->get_filename ();
     filesel_close_cb (fs);
 
-    ResourceManager::load (filename);
-    update_title ();
+    if (ResourceManager::load (new_filename))
+    {
+	filename = new_filename;
+	update_title ();
+    }
 }
 
 void GUI::MainWin::filesel_export_cb (Gtk::FileSelection *fs)
