@@ -1,4 +1,4 @@
-//$Id: menu-res.cc,v 1.9 2001/09/02 20:06:03 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.cc,v 1.10 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -91,60 +91,43 @@ void Menu::set_submenus (const vector<Submenu>& new_menu)
     changed ();
 }
 
-bool Menu::load (xmlDocPtr doc,
-		 xmlNodePtr node)
+bool Menu::load (StorageNode &node)
 {
-#define XML_HAS_NAME(node,val) (!strcmp ((char*)node->name, val))
-    
-    for (xmlNodePtr curr_node  = node->xmlChildrenNode;
-	 curr_node != NULL;
-	 curr_node  = curr_node->next)
+    for (StorageNode curr_node  = node.children ();
+	 curr_node; curr_node++)
     {
-	if (XML_HAS_NAME (curr_node, "submenu"))
+	if (curr_node.name () == "submenu")
 	{
 	    Submenu submenu;
-	    gchar *xml_label = (gchar*)xmlGetProp (curr_node, (xmlChar*)"label");
+	    string label = curr_node.get_prop<string> ("label");
 	    
-	    if (!xml_label)
+	    if (label == "")
 		break;
-
-	    submenu.label = xml_label;
-	    xmlFree (xml_label);
 	    
-	    for (xmlNodePtr sub_node = curr_node->xmlChildrenNode;
-		 sub_node != NULL;
-		 sub_node = sub_node->next)
+	    submenu.label = label;
+	    
+	    for (StorageNode sub_node = curr_node.children ();
+		 sub_node; sub_node++)
 	    {
 		MenuItem menu_item;
-		
-		if (XML_HAS_NAME (sub_node, "menuitem"))
+		if (sub_node.name () == "menuitem")
 		{
-		    gchar *xml_id = (gchar*)xmlGetProp (sub_node, (xmlChar*)"id");
-		    gchar *xml_label = (gchar*)xmlGetProp (sub_node, (xmlChar*)"label");
-		    gchar *xml_shortcut = (gchar*)xmlGetProp (sub_node, (xmlChar*)"shortcut");
+		    string id = sub_node.get_prop<string> ("id");
+		    string label = sub_node.get_prop<string> ("label");
+		    char   shortcut = sub_node.get_prop<char> ("shortcut");
 
-		    if (!xml_label || !xml_id)
+		    if (id == "" || label == "")
 			break;
 
 		    menu_item.separator = false;
 
-		    menu_item.id = xml_id;
-		    xmlFree (xml_id);
-
-		    menu_item.label = xml_label;
-		    xmlFree (xml_label);
-
-		    if (xml_shortcut)
-		    {
-			menu_item.shortcut = xml_shortcut[0];
-			xmlFree (xml_shortcut);
-		    } else {
-			menu_item.shortcut = 0;
-		    }
+		    menu_item.id = id;
+		    menu_item.label = label;		    
+		    menu_item.shortcut = shortcut;
 
 		    submenu.items.push_back (menu_item);
 		}
-		else if (XML_HAS_NAME (sub_node, "separator"))
+		else if (sub_node.name () == "separator")
 		{
 		    menu_item.separator = true;
 
@@ -153,14 +136,15 @@ bool Menu::load (xmlDocPtr doc,
 		else
 		    g_warning ("Error parsing `menu' resource: "
 			       "unexpected element `%s/%s'",
-			       curr_node->name, sub_node->name);
+			       curr_node.name ().c_str (),
+			       sub_node.name ().c_str ());
 	    }
 
 	    submenus.push_back (submenu);
 	}	    
 	else
 	    g_warning ("Error parsing `menu' resource: "
-		       "unexpected element `%s'", curr_node->name);
+		       "unexpected element `%s'", curr_node.name ().c_str ());
 
     }
     
@@ -169,36 +153,29 @@ bool Menu::load (xmlDocPtr doc,
     return true;
 }
 
-void Menu::save (xmlNodePtr node) const
+void Menu::save (StorageNode &node) const
 {
-    xmlNodePtr submenu_node, item_node;
+    StorageNode submenu_node, item_node;
     
     for (vector<Submenu>::const_iterator i = submenus.begin ();
 	 i != submenus.end (); i++)
     {
-	submenu_node = xmlNewChild (node, NULL, (xmlChar*) "submenu", NULL);
-	xmlSetProp (submenu_node, (xmlChar*) "label",
-		    (xmlChar*) i->label.c_str ());
+	submenu_node = node.add_node ("submenu");
+	submenu_node.set_prop ("label", i->label);
 
 	for (vector<MenuItem>::const_iterator j = i->items.begin ();
 	     j != i->items.end (); j++)
 	{
 	    if (j->separator)
 	    {
-		item_node = xmlNewChild (submenu_node, NULL, (xmlChar*) "separator", NULL);
+		submenu_node.add_node ("separator");
 	    } else {
-		item_node = xmlNewChild (submenu_node, NULL, (xmlChar*) "menuitem", NULL);
-		xmlSetProp (item_node, (xmlChar*) "id",
-			    (xmlChar*) j->id.c_str ());
-		xmlSetProp (item_node, (xmlChar*) "label",
-			    (xmlChar*) j->label.c_str ());
+		item_node = submenu_node.add_node ("menuitem");
+		item_node.set_prop ("id",    j->id);
+		item_node.set_prop ("label", j->label);
+
 		if (j->shortcut)
-		{
-		    gchar *shortcut_str = g_strdup_printf ("%c", j->shortcut);
-		    xmlSetProp (item_node, (xmlChar*) "shortcut",
-				(xmlChar*) shortcut_str);
-		    xmlFree (shortcut_str);    
-		}
+		    item_node.set_prop ("shortcut", j->shortcut);
 	    }
 	}
     }
