@@ -1,4 +1,4 @@
-//$Id: resource-manager-io.cc,v 1.12 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.13 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,10 +49,8 @@ void ResourceManager::reset ()
     dirty = false;
 }
 
-void ResourceManager::load (const string& filename)
+bool ResourceManager::load (const string& filename)
 {
-    reset ();
-
     Storage storage;
 
     if (!storage.load (filename))
@@ -62,7 +60,7 @@ void ResourceManager::load (const string& filename)
 	GUI::show_error (buffer);
 	g_free (buffer);
 
-	return;
+	return false;
     }
 	
     StorageNode root_node = storage.get_root ();
@@ -73,12 +71,14 @@ void ResourceManager::load (const string& filename)
 					 g_basename (filename.c_str ()));
 	GUI::show_error (buffer);
 	g_free (buffer);
-        return;
+        return false;
     }
 
     /*
      * Walk the tree
      */
+    reset ();
+
     for (StorageNode curr_node = root_node.children ();
          curr_node; curr_node++)
     {
@@ -89,6 +89,7 @@ void ResourceManager::load (const string& filename)
     }
     
     dirty = false;
+    return true;
 }
 
 Resources::Resource* ResourceManager::load_resource (StorageNode &node)
