@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.12 2001/10/20 16:06:50 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.13 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -85,10 +85,25 @@ void ResourceManager::unregister_id (const string& id)
     id_set.erase (id);
 }
 
+string ResourceManager::validate_id (const string &id)
+{
+    string valid_id = id;
+    
+    string allowed_characters =
+	"abcdefghijklmnopqrstuvwxyz_ABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789";
+    
+    for (string::iterator i = valid_id.begin ();
+	 i != valid_id.end (); i++)
+	if (allowed_characters.find (*i) == string::npos)
+	    *i = '_';
+
+    return valid_id;
+}
+
 Resources::Resource* ResourceManager::create_resource (Resources::Type  type,
 						       const string    &id_ = "")
 {
-    string id = id_;
+    string id = validate_id (id_);
     
     if (id == "")
 	id = create_id (Resources::type_id_from_type (type));
