@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.8 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.9 2001/10/28 14:08:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,7 +51,8 @@ namespace Guikachu
 	static bool register_id   (const string &id);
 	static void unregister_id (const string &id);
 
-	static string create_id (const string &prefix);
+	static string create_id   (const string &prefix);
+	static string validate_id (const string &id);
 
 	static set<Resources::Resource*> get_resources ();
 	static Resources::Resource* get_resource (const string &id);
@@ -64,7 +65,7 @@ namespace Guikachu
 	// Persistance
 	static void reset ();
 	static bool is_dirty ();
-	static void load (const string &filename);
+	static bool load (const string &filename);
 	static void save (const string &filename);
 	static void export_rcp (const string &filename); 
 
