@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.12 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.13 2001/10/19 20:17:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -33,7 +33,8 @@ namespace Guikachu
 	    RESOURCE_DIALOG,
 	    RESOURCE_STRING,
 	    RESOURCE_MENU,
-	    RESOURCE_FORM
+	    RESOURCE_FORM,
+	    RESOURCE_BLOB
 	};
 	
 	class Resource;
