@@ -1,4 +1,4 @@
-//$Id: resource-combo.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.cc,v 1.3 2001/10/30 17:34:48 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,12 +26,11 @@
 
 using namespace Guikachu;
 
-GUI::ResourceCombo::ResourceCombo (Resources::Type   type_,
-				   Property<string> &property_):
+GUI::ResourceCombo::ResourceCombo (Resources::Type          type_,
+				   Properties::ResourceRef &property_):
     Gtk::HBox (false, 5),
     button_edit (_("Edit...")),
     type (type_),
-    current (""),
     property (property_)
 {
     combo.set_value_in_list (true, true);
@@ -69,13 +68,13 @@ void GUI::ResourceCombo::add_resource (Resources::Resource *res)
 
     update_block = true;
 
+    string current = property;
+    
     Gtk::ListItem *item = new Gtk::ListItem (res->id);
     item->set_user_data (res);
     item->show ();
     combo.get_list ()->add (*manage (item));
 
-    if (res->id == current)
-	current_res = res;
     combo.get_entry ()->set_text (current);
 
     res->changed.connect (bind (slot (this, &ResourceCombo::resource_changed_cb),
@@ -100,26 +99,20 @@ void GUI::ResourceCombo::remove_resource (Resources::Resource *res)
     }
 
     update_block = false;
-
-    if (res->id == current)
-	property = "";
 }
 
 void GUI::ResourceCombo::update ()
 {
     update_block = true;
 
-    current = property;
-    current_res = ResourceManager::get_resource (current);
-    
-    combo.get_entry ()->set_text (current);
+    combo.get_entry ()->set_text (property);
 
     update_block = false;
 }
 
 void GUI::ResourceCombo::edit_cb ()
 {
-    Resources::Resource *res = ResourceManager::get_resource (current);
+    Resources::Resource *res = ResourceManager::get_resource (property);
     g_return_if_fail (res != 0);
     
     res->show_ui ();
@@ -130,7 +123,7 @@ void GUI::ResourceCombo::entry_cb ()
     if (!update_block)
 	property = combo.get_entry ()->get_text ();
     
-    if (current != "")
+    if (property != "")
 	button_edit.set_sensitive (true);
     else
 	button_edit.set_sensitive (false);
@@ -138,9 +131,6 @@ void GUI::ResourceCombo::entry_cb ()
 
 void GUI::ResourceCombo::resource_changed_cb (Resources::Resource *res)
 {
-    if (res == current_res)
-	combo.get_entry ()->set_text (res->id);
-    
     update_block = true;
 
     using namespace Gtk::List_Helpers;
