@@ -1,4 +1,4 @@
-//$Id: string-list.h,v 1.3 2001/08/10 16:10:36 cactus Exp $ -*- c++ -*-
+//$Id: string-list.h,v 1.4 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,6 +24,8 @@
 #include <gtk--/button.h>
 #include <gtk--/entry.h>
 
+#include "property.h"
+
 #include <vector>
 
 namespace Guikachu
@@ -34,21 +36,14 @@ namespace Guikachu
 	{
 	    typedef vector<string> value_t;
 
-	    typedef SigC::Slot0<value_t> get_slot_t;
-	    typedef SigC::Slot1<void, const value_t&> set_slot_t;
-	    typedef SigC::Signal0<void> changed_t;
-	    
-	    get_slot_t get_val;
-	    set_slot_t set_val;
+	    Property<value_t> &property;
 
 	    Gtk::List   *list_widget;
 	    Gtk::Button *btnAdd, *btnUp, *btnDown, *btnRemove;
 	    Gtk::Entry  *entry;
 	    
 	public:
-	    StringList (get_slot_t get_slot,
-			set_slot_t set_slot,
-			changed_t& changed);
+	    StringList (Property<value_t> &property);
 	private:
 	    bool update_block;
 	    void update ();
